Bose SoundTouch Python Wrapper for AsyncIO
==========================================

.. image:: https://readthedocs.org/projects/aiobosest/badge/?version=latest
  :target: http://aiobosest.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. image:: https://www.gnu.org/graphics/gplv3-127x51.png
  :target:  https://www.gnu.org/licenses/gpl-3.0.html

About
-----

Powered by the Bose® SoundTouch® `Developers API`_.

.. _Developers API: http://developers.bose.com

Features
--------

- Support GET and POST using the REST API
- WebSocket connection to receive updates from the system

Getting Started
---------------

A simple client example is provided on the examples/ directory.

Documentation
-------------

https://aiobosest.readthedocs.io/

Requirements
------------

- Python >= 3.5
- aiohttp_
- lxml_
- zeroconf_

.. _aiohttp: https://github.com/KeepSafe/aiohttp
.. _lxml: http://lxml.de/
.. _zeroconf: https://github.com/jstasiak/python-zeroconf

License
-------

``aiobosest`` is offered under the GPLv3_ license.

.. _GPLv3: https://www.gnu.org/licenses/gpl-3.0.html

Source code
------------

The latest version is available in a github repository:
https://github.com/trunet/aiobosest

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
